==> parodia_admin-1.0.2.tar.gz: lib/core/repository/stores.repository.dart <==
// GET
// /api/v1/dashboard/stores/{id}

// PUT
// /api/v1/dashboard/stores/{id}

// DELETE
// /api/v1/dashboard/stores/{id}

// GET
// /api/v1/dashboard/stores

// POST
// /api/v1/dashboard/stores

// POST
// /api/v1/dashboard/stores/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/store.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreRepository {
  ParodiaHTTP? _http;

  StoreRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<StoreDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stores',
      param: id,
    );

    return ResponseItemDTO<StoreDTO>(
      response: response,
      fromJson: StoreDTO.fromJson,
    );
  }

  Future<ResponseListDTO<StoreDTO>> getAll({StoreParentQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stores',
      query: query,
    );

    return ResponseListDTO<StoreDTO>(
      response: response,
      fromJson: StoreDTO.fromJson,
    );
  }

  // Future<ResponseItemDTO> create({StoreBody? store}) async {
  //   final response = await _http!.request(
  //     requestType: RequestType.post,
  //     path: '/stores',
  //     data: store,
  //   );

  //   return ResponseItemDTO(
  //     response: response,
  //     fromJson: null,
  //   );
  // }

  // Future<ResponseItemDTO> update({String? id, StoreBody? store}) async {
  //   final response = await _http!.request(
  //     requestType: RequestType.put,
  //     path: '/stores',
  //     param: id,
  //     data: store,
  //   );

  //   return ResponseItemDTO(
  //     response: response,
  //     fromJson: null,
  //   );
  // }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/stores',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/stores/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/stores.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/stores/{id}

// PUT
// /api/v1/dashboard/dashboard/stores/{id}

// DELETE
// /api/v1/dashboard/dashboard/stores/{id}

// GET
// /api/v1/dashboard/dashboard/stores

// POST
// /api/v1/dashboard/dashboard/stores

// POST
// /api/v1/dashboard/dashboard/stores/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/store.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreRepository {
  ParodiaHTTP? _http;

  StoreRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<StoreDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stores',
      param: id,
    );

    return ResponseItemDTO<StoreDTO>(
      response: response,
      fromJson: StoreDTO.fromJson,
    );
  }

  Future<ResponseListDTO<StoreDTO>> getAll({StoreParentQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stores',
      query: query,
    );

    return ResponseListDTO<StoreDTO>(
      response: response,
      fromJson: StoreDTO.fromJson,
    );
  }

  // Future<ResponseItemDTO> create({StoreBody? store}) async {
  //   final response = await _http!.request(
  //     requestType: RequestType.post,
  //     path: '/dashboard/stores',
  //     data: store,
  //   );

  //   return ResponseItemDTO(
  //     response: response,
  //     fromJson: null,
  //   );
  // }

  // Future<ResponseItemDTO> update({String? id, StoreBody? store}) async {
  //   final response = await _http!.request(
  //     requestType: RequestType.put,
  //     path: '/dashboard/stores',
  //     param: id,
  //     data: store,
  //   );

  //   return ResponseItemDTO(
  //     response: response,
  //     fromJson: null,
  //   );
  // }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/stores',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stores/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
